@@ -13,11 +13,11 @@ class LoveFapCrawler:
         self.SQL_Helper = SQL_Helper
         self.quiet = quiet
 
-    async def fetch(self, session: ScrapeSession, url: URL):
+    async def fetch(self, session: ScrapeSession, url: URL) -> AlbumItem:
         """Director for lovefap scraping"""
         album_obj = AlbumItem("Loose LoveFap Files", [])
 
-        await log(f"[green]Starting: {str(url)}[/green]", quiet=self.quiet)
+        await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
         if await check_direct(url):
             url_path = await get_db_path(url)
             complete = await self.SQL_Helper.check_complete_singular("lovefap", url_path)
@@ -25,7 +25,7 @@ class LoveFapCrawler:
             media = MediaItem(url, url, complete, filename, ext, filename)
             await album_obj.add_media(media)
             await self.SQL_Helper.insert_album("lovefap", "", album_obj)
-            await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+            await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
             return album_obj
 
         try:
@@ -36,13 +36,13 @@ class LoveFapCrawler:
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"[red]Error: {str(url)}[/red]", quiet=self.quiet)
+            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
             logger.debug(e)
             return album_obj
 
         url_path = await get_db_path(url)
-        await self.SQL_Helper.insert_album("cyberdrop", url_path, album_obj)
-        await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+        await self.SQL_Helper.insert_album("lovefap", url_path, album_obj)
+        await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
         return album_obj
 
     async def fetch_album(self, session: ScrapeSession, url: URL, album_obj: AlbumItem):
