@@ -1,5 +1,6 @@
 import shutil
 from base64 import b64encode
+from enum import IntEnum
 from http import HTTPStatus
 from pathlib import Path
 
@@ -7,6 +8,11 @@ from cyberdrop_dl.base_functions.base_functions import FILE_FORMATS
 from cyberdrop_dl.base_functions.data_classes import MediaItem
 
 
+class CustomHTTPStatus(IntEnum):
+    WEB_SERVER_IS_DOWN = 521
+    IM_A_TEAPOT = 418
+
+
 async def allowed_filetype(media: MediaItem, block_images: bool, block_video: bool, block_audio: bool, block_other: bool):
     """Checks whether the enclosed file is allowed to be downloaded"""
     ext = media.ext
